@@ -1,10 +1,10 @@
 import asyncio
+from bergen.wards.main import MainWard
+from bergen.config.types import ArkitektConfig, HerreConfig
+from bergen.schemas.herre.types import User
 from bergen.schema import Transcript
-from bergen.hookable.base import Hookable, Hooks
-from oauthlib.oauth2.rfc6749.clients.base import Client
-
+from bergen.hookable.base import Hooks
 from pydantic.main import BaseModel
-from bergen.auths.types import User
 from typing import Dict
 from bergen.wards.graphql.aiohttp import AIOHttpGraphQLWard
 from bergen.enums import ClientType, HostProtocol, PostmanProtocol, ProviderProtocol
@@ -13,10 +13,11 @@ from bergen.auths.base import BaseAuthBackend
 from bergen.wards.base import BaseWard
 from bergen.postmans.base import BasePostman
 import logging
-from threading import Thread
+
 from bergen.console import console
 from rich.panel import Panel
 from rich.table import Table
+
 from rich import pretty
 pretty.install()
 from rich.traceback import install
@@ -25,17 +26,6 @@ install()
 logger = logging.getLogger(__name__)
 import os
 
-def start_background_loop(loop: asyncio.AbstractEventLoop) -> None:
-    asyncio.set_event_loop(loop)
-
-
-class ArkitektConfig(BaseModel):
-    secure: bool
-    host: str
-    port: int
-
-    def __str__(self) -> str:
-        return f"{'Secure' if self.secure else 'Insecure'} Connection to Arkitekt on {self.host}:{self.port}"
 
 
 
@@ -45,16 +35,13 @@ class BaseBergen:
     def __init__(self, auth: BaseAuthBackend, config: ArkitektConfig , 
             bind=True,
             log=logging.INFO,
-            jupyter=False,
             client_type: ClientType = ClientType.CLIENT,
             log_stream=False,
             auto_connect=False,
             **kwargs) -> None:
         
-        if jupyter:
-            setLogging(logging.ERROR, log_stream=False)
-        else:
-            setLogging(log, log_stream=log_stream)
+        
+        setLogging(log, log_stream=log_stream)
 
        
         if bind: 
@@ -62,8 +49,12 @@ class BaseBergen:
             from bergen.registries.client import set_current_client
             set_current_client(self)
 
+
+
         self.auth = auth
 
+
+
         self.application = self.auth.application
 
 
@@ -106,10 +97,7 @@ class BaseBergen:
             return self.main_ward
 
         if self._transcript is None:
-            if self.running_in_sync:
-                raise Exception("Not negotiated Error: Please negotiate first or set auto_negotiate=True")
-            else:
-                raise Exception("You are running in event Loop: Please await self.negotiate_async first or run with 'async with Bergen(....)'")
+            raise Exception("Not Negotiated yet!")
 
         if identifier in self.identifierWardMap:
             return self.identifierWardMap[identifier]
@@ -123,7 +111,7 @@ class BaseBergen:
         if settings.type == PostmanProtocol.RABBITMQ:
             try:
                 from bergen.postmans.pika import PikaPostman
-                postman = PikaPostman(**settings.kwargs, loop=self.loop, client=self, hooks=self.registered_hooks)
+                postman = PikaPostman(self, **settings.kwargs, hooks=self.registered_hooks)
             except ImportError as e:
                 logger.error("You cannot use the Pika Postman without installing aio_pika")
                 raise e
@@ -131,7 +119,7 @@ class BaseBergen:
         elif settings.type == PostmanProtocol.WEBSOCKET:
             try:
                 from bergen.postmans.websocket import WebsocketPostman
-                postman = WebsocketPostman(**settings.kwargs, loop=self.loop, client=self, hooks=self.registered_hooks)
+                postman = WebsocketPostman(self, **settings.kwargs, hooks=self.registered_hooks)
             except ImportError as e:
                 logger.error("You cannot use the Websocket Postman without installing websockets")
                 raise e
@@ -147,7 +135,7 @@ class BaseBergen:
         if settings.type == ProviderProtocol.WEBSOCKET:
             try:
                 from bergen.provider.websocket import WebsocketProvider
-                provider = WebsocketProvider(**settings.kwargs, loop=self.loop, client=self, hooks=self.registered_hooks)
+                provider = WebsocketProvider(self, **settings.kwargs, hooks=self.registered_hooks)
             except ImportError as e:
                 logger.error("You cannot use the Websocket Provider without installing websockets")
                 raise e
@@ -157,13 +145,13 @@ class BaseBergen:
 
         return provider
 
-    def getEntertainerFromSettings(self, transcript):
+    def getEntertainerFromSettings(self, transcript: Transcript):
         settings = transcript.host
 
         if settings.type == HostProtocol.WEBSOCKET:
             try:
                 from bergen.entertainer.websocket import WebsocketEntertainer
-                provider = WebsocketEntertainer(**settings.kwargs, loop=self.loop, client=self, hooks=self.registered_hooks)
+                provider = WebsocketEntertainer(self, **settings.kwargs, hooks=self.registered_hooks)
             except ImportError as e:
                 logger.error("You cannot use the Websocket Entertainer without installing websockets")
                 raise e
@@ -176,31 +164,28 @@ class BaseBergen:
     async def negotiate_async(self):
         self.loop = asyncio.get_event_loop()
 
-        from bergen.queries.initiation import NEGOTIATION_GQL
+        from bergen.schemas.arkitekt.mutations.negotiate import NEGOTIATION_GQL
         from bergen.registries.datapoint import get_datapoint_registry
 
         # Instantiate our Main Ward, this is only for Nodes and Pods
-        self.main_ward = AIOHttpGraphQLWard(host=self.host, port=self.port, protocol=self.protocol, token=self.auth.access_token, loop=self.loop)
+        self.main_ward = MainWard(self)
         await self.main_ward.configure()
 
         # We resort escalating to the different client Type protocols
-        print(self.negotiate_additionals)
         self._transcript = await NEGOTIATION_GQL.run_async(ward=self.main_ward, variables={"clientType": self.client_type, **self.negotiate_additionals})
-        
+        print(self._transcript)
 
         #Lets create our different Wards 
         
         assert self._transcript.models is not None, "We apparently didnt't get any points"
-        
         datapoint_registry = get_datapoint_registry()
 
 
         self.identifierDataPointMap = {model.identifier.lower(): model.point for model in self._transcript.models}
-        self.identifierWardMap = {model.identifier.lower(): datapoint_registry.createWardForDatapoint(model.point, self) for model in self._transcript.models}
+        self.identifierWardMap = {model.identifier.lower(): datapoint_registry.create_ward(self, model.point) for model in self._transcript.models}
 
         # Negotating Extensions for the Datapoints
-        self._extensions = await datapoint_registry.configureWards()
-        print(self._extensions)
+        self._extensions = await datapoint_registry.configure_wards()
 
         self.postman = self.getPostmanFromSettings(self._transcript)
         await self.postman.connect()
@@ -229,10 +214,27 @@ class BaseBergen:
 
         herre_table = Table(title="Herre", show_header=False)
         for key, value in self.auth.config.dict().items():
-            if key == "client_secret": continue
+            if "secret" in key: continue
             herre_table.add_row(key, str(value))
+
+        extensions_table = Table.grid()
+
+        row = []
+        for key, value in self._extensions.items():
+            if isinstance(value, dict):
+                extensions_table.add_column()
+                sub_table = Table(title=key, show_header=False)
+                for key, value in value.items():
+                    sub_table.add_row(key, str(value))
+
+                row.append(sub_table)
+
+        extensions_table.add_row(*row)
+
+
         table.add_row("Welcome to Arnheim")
         table.add_row(herre_table, arkitekt_table)
+        
 
         table.add_row()
 
@@ -243,6 +245,7 @@ class BaseBergen:
 
         table.add_row()
         table.add_row("[green]Connected :pile_of_poo:")
+        table.add_row(extensions_table)
 
         console.print(Panel(table, title="Arkitekt"))
 
@@ -340,7 +343,6 @@ class BaseBergen:
 
         return real_decorator
 
-
     def enable(self, *args, **kwargs):
         if self._provider:
             return self.provider.enable(*args, **kwargs)
