@@ -19,17 +19,16 @@ class DataPointRegistry(object):
         self.pointIDPointMap: Dict[str, DataPoint] = {}
         self.pointIDWardMap: Dict[str, BaseWard] = {}
         self.pointIDNegotiationMap: Dict[str, BaseWard] = {}
-
-
         self.builders =  {
                 # Default Builders for standard
-                DataPointType.GRAPHQL: lambda datapoint, bergen: AIOHttpGraphQLWard(host=datapoint.outward, port=datapoint.port, token=bergen.auth.getToken(), protocol="http", loop=bergen.loop, needs_negotiation=datapoint.needsNegotiation)
+                DataPointType.GRAPHQL: AIOHttpGraphQLWard
         }
 
-    def registerClientBuilder(self, type:str , builder: Callable):
+
+    def register_client_builder(self, type:str , builder: Callable):
         self.builders[type] = builder
 
-    def createWardForDatapoint(self, point, bergen) -> BaseWard:
+    def create_ward(self, bergen, point) -> BaseWard:
 
         if point.app.name == bergen.application.name:
             console.log("[red] Datapoint App is the Same as this One, will not create own Ward!!!")
@@ -42,26 +41,25 @@ class DataPointRegistry(object):
 
         if point.type in self.builders:
             builder = self.builders[point.type]
-            self.pointIDWardMap[point.id]  = builder(point, bergen)
+            self.pointIDWardMap[point.id]  = builder(bergen, point)
             self.pointIDPointMap[point.id]  = point
 
             return self.pointIDWardMap[point.id]
         else:
             raise NotImplementedError(f"We have no idea how to build the ward for this Datapoint {point.type}")
 
-    async def configureWards(self):
+    async def configure_wards(self):
         wards = [ward for id, ward in self.pointIDWardMap.items()]
         names = [point.app.name for id, point in self.pointIDPointMap.items()]
 
-        await asyncio.gather(*[ward.configure() for ward in wards], return_exceptions=True)
-        negotiation_results = await asyncio.gather(*[ward.negotiate() for ward in wards], return_exceptions=True)
+        negotiation_results = await asyncio.gather(*[ward.configure() for ward in wards], return_exceptions=True)
+        print(negotiation_results)
         extensions =  {name: result for name, result in zip(names, negotiation_results)}
         return extensions
 
 
 
 
-
 def get_datapoint_registry() -> DataPointRegistry:
     global datapointregistry
     if datapointregistry is None:
